package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.entity.TaPerson;
import com.yunzhi.marketing.service.ITaPersonService;
import com.yunzhi.marketing.xlk.entity.SearchHouse;
import com.yunzhi.marketing.xlk.service.ISearchHouseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 帮我找房  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-05-19
 */
@RestController
@RequestMapping("/api")
@Api(value = "帮我找房", tags = "xlk-帮我找房")
public class SearchHouseController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SearchHouseController.class);

    @Autowired
    public ISearchHouseService iSearchHouseService;

    @Autowired
    public ITaPersonService taPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "获取帮我找房列表", notes = "获取帮我找房列表")
    @RequestMapping(value="/searchHouse",method= RequestMethod.GET)
    public ResponseBean searchHouseList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SearchHouse> pg = new Page<>(pageNum, pageSize);
            LambdaQueryWrapper<SearchHouse> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.orderByDesc(SearchHouse::getCreatedTime);

            IPage<SearchHouse> result = iSearchHouseService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("searchHouseList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param searchHouse 实体对象
     * @return
     */
    @ApiOperation(value = "保存帮我找房需求", notes = "保存帮我找房需求")
    @RequestMapping(value="/app/searchHouse",method= RequestMethod.POST)
    public ResponseBean searchHouseAdd(@RequestBody SearchHouse searchHouse, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        String openid = getOpenId(request);
        Integer orgId = getOrgId(request);
        List<TaPerson> persons = taPersonService.getPersonsByOpenId(openid);
        if (null == persons || persons.size() == 0) {
            return ResponseBean.error("当前账户信息异常, 清除缓存重试", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = persons.get(0);
        try {
            searchHouse.setPersonId(person.getPersonId());
            searchHouse.setOrgId(orgId);
            if (iSearchHouseService.save(searchHouse)){
                responseBean.addSuccess(searchHouse);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("searchHouseAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ApiOperation(value = "根据id删除帮我找房需求", notes = "根据id删除帮我找房需求")
    @ResponseBody
    @RequestMapping(value="/searchHouse/{id}", method= RequestMethod.DELETE)
    public ResponseBean searchHouseDelete(@PathVariable Integer id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSearchHouseService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("searchHouseDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param searchHouse 实体对象
     * @return
     */
    @ApiOperation(value = "修改帮我找房需求", notes = "修改帮我找房需求")
    @RequestMapping(value="/searchHouse/{id}",method= RequestMethod.PUT)
    public ResponseBean searchHouseUpdate(@PathVariable Integer id,
                                          @RequestBody SearchHouse searchHouse, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSearchHouseService.updateById(searchHouse)){
                responseBean.addSuccess(searchHouse);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("searchHouseUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @ApiOperation(value = "根据id查询帮我找房需求详情", notes = "根据id查询帮我找房需求详情")
    @RequestMapping(value="/searchHouse/{id}",method= RequestMethod.GET)
    public ResponseBean searchHouseGet(@PathVariable Integer id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSearchHouseService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("searchHouseDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
